@@ -11,6 +11,7 @@ from airflow.contrib.operators.kubernetes_pod_operator import KubernetesPodOpera
 from airflow.models import BaseOperator
 from airflow.operators.python_operator import PythonOperator, BranchPythonOperator
 from airflow.sensors.http_sensor import HttpSensor
+from airflow.sensors.sql_sensor import SqlSensor
 from airflow.utils.module_loading import import_string
 from airflow import __version__ as AIRFLOW_VERSION
 
@@ -210,6 +211,43 @@ class DagBuilder:
                 del task_params["python_callable_name"]
                 del task_params["python_callable_file"]
 
+            # Check for the custom success and failure callables in SqlSensor. These are considered
+            # optional, so no failures in case they aren't found. Note: there's no reason to
+            # declare both a callable file and a lambda function for success/failure parameter.
+            # If both are found the object will not throw and error, instead callable file will
+            # take precedence over the lambda function
+            if operator_obj in [SqlSensor]:
+                # Success checks
+                if task_params.get("success_check_file") and task_params.get(
+                    "success_check_name"
+                ):
+                    task_params["success"]: Callable = utils.get_python_callable(
+                        task_params["success_check_name"],
+                        task_params["success_check_file"],
+                    )
+                    del task_params["success_check_name"]
+                    del task_params["success_check_file"]
+                elif task_params.get("success_check_lambda"):
+                    task_params["success"]: Callable = utils.get_python_callable_lambda(
+                        task_params["success_check_lambda"]
+                    )
+                    del task_params["success_check_lambda"]
+                # Failure checks
+                if task_params.get("failure_check_file") and task_params.get(
+                    "failure_check_name"
+                ):
+                    task_params["failure"]: Callable = utils.get_python_callable(
+                        task_params["failure_check_name"],
+                        task_params["failure_check_file"],
+                    )
+                    del task_params["failure_check_name"]
+                    del task_params["failure_check_file"]
+                elif task_params.get("failure_check_lambda"):
+                    task_params["failure"]: Callable = utils.get_python_callable_lambda(
+                        task_params["failure_check_lambda"]
+                    )
+                    del task_params["failure_check_lambda"]
+
             if operator_obj in [HttpSensor]:
                 if not (
                     task_params.get("response_check_name")
@@ -233,7 +271,7 @@ class DagBuilder:
                     task_params[
                         "response_check"
                     ]: Callable = utils.get_python_callable_lambda(
-                        task_params["response_check_lambda"],
+                        task_params["response_check_lambda"]
                     )
                     # remove dag-factory specific parameters
                     # Airflow 2.0 doesn't allow these to be passed to operator
@@ -287,6 +325,12 @@ class DagBuilder:
                 )
                 del task_params["execution_timeout_secs"]
 
+            if utils.check_dict_key(task_params, "sla_secs"):
+                task_params["sla"]: timedelta = timedelta(
+                    seconds=task_params["sla_secs"]
+                )
+                del task_params["sla_secs"]
+
             if utils.check_dict_key(task_params, "execution_delta_secs"):
                 task_params["execution_delta"]: timedelta = timedelta(
                     seconds=task_params["execution_delta_secs"]
@@ -412,41 +456,63 @@ class DagBuilder:
         :type: Dict[str, Union[str, DAG]]
         """
         dag_params: Dict[str, Any] = self.get_dag_params()
-        dag: DAG = DAG(
-            dag_id=dag_params["dag_id"],
-            schedule_interval=dag_params.get("schedule_interval", timedelta(days=1)),
-            description=(
-                dag_params.get("description", None)
-                if version.parse(AIRFLOW_VERSION) >= version.parse("1.10.11")
-                else dag_params.get("description", "")
-            ),
-            concurrency=dag_params.get(
-                "concurrency",
-                configuration.conf.getint("core", "dag_concurrency"),
-            ),
-            catchup=dag_params.get(
-                "catchup",
-                configuration.conf.getboolean("scheduler", "catchup_by_default"),
-            ),
-            max_active_runs=dag_params.get(
-                "max_active_runs",
-                configuration.conf.getint("core", "max_active_runs_per_dag"),
-            ),
-            dagrun_timeout=dag_params.get("dagrun_timeout", None),
-            default_view=dag_params.get(
-                "default_view", configuration.conf.get("webserver", "dag_default_view")
-            ),
-            orientation=dag_params.get(
-                "orientation",
-                configuration.conf.get("webserver", "dag_orientation"),
-            ),
-            sla_miss_callback=dag_params.get("sla_miss_callback", None),
-            on_success_callback=dag_params.get("on_success_callback", None),
-            on_failure_callback=dag_params.get("on_failure_callback", None),
-            default_args=dag_params.get("default_args", None),
-            doc_md=dag_params.get("doc_md", None),
+
+        dag_kwargs: Dict[str, Any] = {}
+
+        dag_kwargs["dag_id"] = dag_params["dag_id"]
+
+        dag_kwargs["schedule_interval"] = dag_params.get(
+            "schedule_interval", timedelta(days=1)
         )
 
+        if version.parse(AIRFLOW_VERSION) >= version.parse("1.10.11"):
+            dag_kwargs["description"] = dag_params.get("description", None)
+        else:
+            dag_kwargs["description"] = dag_params.get("description", "")
+
+        if version.parse(AIRFLOW_VERSION) >= version.parse("2.2.0"):
+            dag_kwargs["max_active_tasks"] = dag_params.get(
+                "max_active_tasks",
+                configuration.conf.getint("core", "max_active_tasks_per_dag"),
+            )
+        else:
+            dag_kwargs["concurrency"] = dag_params.get(
+                "concurrency", configuration.conf.getint("core", "dag_concurrency")
+            )
+
+        dag_kwargs["catchup"] = dag_params.get(
+            "catchup", configuration.conf.getboolean("scheduler", "catchup_by_default")
+        )
+
+        dag_kwargs["max_active_runs"] = dag_params.get(
+            "max_active_runs",
+            configuration.conf.getint("core", "max_active_runs_per_dag"),
+        )
+
+        dag_kwargs["dagrun_timeout"] = dag_params.get("dagrun_timeout", None)
+
+        dag_kwargs["default_view"] = dag_params.get(
+            "default_view", configuration.conf.get("webserver", "dag_default_view")
+        )
+
+        dag_kwargs["orientation"] = dag_params.get(
+            "orientation", configuration.conf.get("webserver", "dag_orientation")
+        )
+
+        dag_kwargs["sla_miss_callback"] = dag_params.get("sla_miss_callback", None)
+
+        dag_kwargs["on_success_callback"] = dag_params.get("on_success_callback", None)
+
+        dag_kwargs["on_failure_callback"] = dag_params.get("on_failure_callback", None)
+
+        dag_kwargs["default_args"] = dag_params.get("default_args", None)
+
+        dag_kwargs["doc_md"] = dag_params.get("doc_md", None)
+
+        dag_kwargs["access_control"] = dag_params.get("access_control", None)
+
+        dag: DAG = DAG(**dag_kwargs)
+
         if dag_params.get("doc_md_file_path"):
             if not os.path.isabs(dag_params.get("doc_md_file_path")):
                 raise Exception("`doc_md_file_path` must be absolute path")
